 /*
 *  file      : libzoom/lib.c
 *  project   : zoomc
 *  with      : Gtk-2
 *
 *  copyright : (C) 2010 - 2011 by Claude Bulin
 *
 *  ZOOMC - GTK+ implementation of the GNU shell command
 *  GNU General Public License
 *
 *  This file is part of ZOOMC.
 * 
 *  ZOOMC is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  at your option) any later version.
 * 
 *  ZOOMC is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with ZOOMC.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>


#include "lib.h"



//
// 
gboolean libutils_find_file( gchar *p_find_file )
{
	gchar      *PathName = NULL;
	
	if( NULL != p_find_file ) {
		if( NULL != (PathName = g_find_program_in_path( p_find_file ))) {
			g_free( PathName );	PathName = NULL;
			return( TRUE );
		}
	}
	
	return( FALSE );
}
/* utils_hexa_to_int : convertit en entier la chaine pointee par 'gchar *Ptr_Hexa' en hexa
*  La chaine doit commencer par 0x..
*  VALUES A = 65  et   a = 97
*/
gint libutils_hexa_to_int (gchar *Ptr_Hexa)
{
	gint     chiffre_hexa = 0;
	/*gint     cpt = 0;*/
	gint     Gint_Ret = 0;
	gboolean Bool_dans_hexa = FALSE;

	/* PRINT_FUNC_LF(); */

	if (NULL == Ptr_Hexa) return (0);
	if ('\0' == *(Ptr_Hexa) || '\0' == *(Ptr_Hexa+1) || '\0' == *(Ptr_Hexa+2) || '\0' == *(Ptr_Hexa+3))  return (0);

	if (*Ptr_Hexa == '0' && (*(Ptr_Hexa+1) == 'x' || *(Ptr_Hexa+1) == 'X')) {
		Ptr_Hexa += 2;
		Bool_dans_hexa = TRUE;
	}

	Gint_Ret = 0;
	while (Bool_dans_hexa) {
		if (g_ascii_isdigit (*Ptr_Hexa)) {
			chiffre_hexa = *Ptr_Hexa - '0';
		}
		else if (g_ascii_isxdigit (*Ptr_Hexa)) {
			if ((gint)*Ptr_Hexa >= 'a')
				chiffre_hexa = *Ptr_Hexa - 'a' + 10;
			else    chiffre_hexa = *Ptr_Hexa - 'A' + 10;
		}
		else Bool_dans_hexa = FALSE;

		if (Bool_dans_hexa) {
			Gint_Ret = 16 * Gint_Ret + chiffre_hexa;
			Ptr_Hexa ++;
		}
	}

	return (Gint_Ret);
}
// TRUE SI LE FICHIER EXISTE SINON FALSE
//
gboolean libutils_test_file_exist (gchar *File)
{
	/*struct stat status;
	gint	    ret;
	ret = stat (File, &status);
	return (ret > -1 && S_ISREG (status.st_mode));*/
	return (g_file_test (File, G_FILE_TEST_IS_REGULAR));
}
// TRUE SI LE DOSSIER EXISTE SINON FALSE
//
gboolean libutils_test_dir_exist (gchar *File)
{
	/*struct stat status;
	gint	    ret;
	ret = stat (File, &status);
	return (ret > -1 && S_ISDIR (status.st_mode));*/
	return (g_file_test (File, G_FILE_TEST_IS_DIR));
}
size_t libutils_get_size_file (gchar *PathName)
{
	FILE   *fp;
	size_t  size = 0;

	if ((fp = fopen (PathName, "r"))) {
		fseek (fp, 0, SEEK_END);
		size = ftell (fp);
		fclose (fp);
	}
	return (size);
}
// SUPPRESSION SIMPLE ALLOC POINTEE PAR LE GLIST ANSI QUE LE GLIST
// 
GList *libutils_remove_glist (GList *New)
{
	GList *list = NULL;
	gchar *ptr = NULL;

	if (New != NULL) {
		list = g_list_first (New);
		while (list) {
			if ((ptr = (gchar*)list->data)) {
				g_free (ptr);
				ptr = NULL;
				list->data = NULL;
			}
			list = g_list_next(list);
		}
		g_list_free (New);
		New = NULL;
	}
	return ((GList *)NULL);
}
// AFFICHE L ICONE A GAUCHE DANS LA BARRE DE TITRE
// 
void libutils_set_default_icone_to_win (GtkWidget *win)
{
	gchar     *LineCommand = NULL;
	GError    *error = NULL;

	LineCommand = g_strdup_printf ("%s/pixmaps/testzoom.png", PACKAGE_DATA_DIR);
	if (TRUE == libutils_test_file_exist (LineCommand)) {
		// LineCommand = g_strdup ("/home/cat/Projects/basebuild-0.0.4/pixmaps/basebuild.png");
	 	gtk_window_set_icon_from_file (GTK_WINDOW(win), LineCommand, &error);
	 	if (error) {
	 		GDK_PIXBUF_ERROR;
			g_critical ("Could not load pixbuf: %s\n", error->message);
			g_error_free (error);
		}
	}
	g_free (LineCommand);
	LineCommand = NULL;
}
// FILE IS PNG ?
//
gboolean FileIs_png (gchar *namefile)
{
	FILE        *fp = NULL;
	size_t       lenread = 0;
	gchar       *buf = NULL;
	gint         cpt;
	gboolean     bool_signature = FALSE;
	
	/*PRINT_FUNC_LF();*/

	buf = (gchar *)g_malloc0 (sizeof(gchar) * 5124);
	if ((fp = fopen (namefile, "rb")) != NULL) {
		lenread = fread (buf, 1, 5120, fp);
		fclose (fp);
	}
	
	for (cpt = 0; cpt < 5120; cpt ++) {
		if(
			buf [ cpt + 0 ] == 0x50 &&	// 'P'
			buf [ cpt + 1 ] == 0x4E &&	// 'N'
			buf [ cpt + 2 ] == 0x47		// 'G'
		    ) {	
		    bool_signature = TRUE;
		    break;
		}
	}
	g_free (buf);
	buf = NULL;

	return (bool_signature);
}
// FILE IS JPG / JPEG ?
//
gboolean FileIs_jpg (gchar *namefile)
{
	FILE        *fp = NULL;
	size_t       lenread = 0;
	gchar       *buf = NULL;
	gint         cpt;
	gboolean     bool_signature = FALSE;
	
	/*PRINT_FUNC_LF();*/

	buf = (gchar *)g_malloc0 (sizeof(gchar) * 5124);
	if ((fp = fopen (namefile, "rb")) != NULL) {
		lenread = fread (buf, 1, 5120, fp);
		fclose (fp);
	}
	
	for (cpt = 0; cpt < 5120; cpt ++) {
		if(
			buf [ cpt + 0 ] == 0x4A &&	// 'J'
			buf [ cpt + 1 ] == 0x46 &&	// 'F'
			buf [ cpt + 2 ] == 0x49	&&	// 'I'
			buf [ cpt + 3 ] == 0x46		// 'F'
		    ) {	
		    bool_signature = TRUE;
		    break;
		}
	}
	g_free (buf);
	buf = NULL;

	return (bool_signature);
}
// 
// 
gboolean FileIs_image( gchar *PathNameFile )
{
	GdkPixbuf *PixBuf = NULL;
	if( NULL != ( PixBuf = gdk_pixbuf_new_from_file( PathNameFile, NULL ))) {
		g_object_unref( PixBuf );
		return( TRUE );
	}
	return( FALSE );
}
// CREATION D UN DOSSIER TEMPORAIRE
//
gchar *libutils_create_temporary_rep( gchar *SrcTmp, gchar *NewRepTmp )
{
	//gchar	*LineCommand = NULL;
	gchar	*Path = NULL;
	
	if( NULL != NewRepTmp ) {
		Path = g_strdup_printf( "%s/%s", SrcTmp, NewRepTmp );
		if( FALSE == libutils_test_dir_exist( Path )) {
			g_print( "CREATE TEMPORARY REP:\n\t%s\n", Path );
			g_mkdir_with_parents( Path, 0700 );
		}
	}
	return( (gchar *)Path );
}
// SUPPRESSION D UN DOSSIER TEMPORAIRE
//
gchar *libutils_remove_temporary_rep( gchar *path_tmprep )
{
	pid_t  pid;

	if( NULL != path_tmprep ) {
		if( (pid = fork ()) == 0 ) {
			execlp (
				"rm",
				"rm",
				"-rf",
				path_tmprep,
				NULL
				);
		}
		g_print( "REMOVE TEMPORARY REP:\n\t%s\n", path_tmprep );
		g_free( path_tmprep );
		path_tmprep = NULL;
	}
	return( (gchar *)NULL );
}

 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
